-- Create new table ApplicationUserRole.
CREATE TABLE ApplicationUserRole (
    ApplicationId int NOT NULL,
    UserId int NOT NULL,
    RoleId int NOT NULL,
    PRIMARY KEY (ApplicationId, UserId, RoleId));


-- Create new table ApplicationUser.
CREATE TABLE ApplicationUser (
    ApplicationId int NOT NULL,
    UserId int NOT NULL,
    PRIMARY KEY (ApplicationId, UserId));


-- Create new table ApplicationRole.
CREATE TABLE ApplicationRole (
    ApplicationId int NOT NULL,
    RoleId int NOT NULL,
    PRIMARY KEY (ApplicationId, RoleId));


-- Create new table Role.
CREATE TABLE Role (
    Id int NOT NULL AUTO_INCREMENT,
    Name VARCHAR(255) NOT NULL,
    LoweredName VARCHAR(255) NOT NULL,
    Description VARCHAR(255) NULL,
    PRIMARY KEY (Id));


-- Create new table MembershipUser.
CREATE TABLE MembershipUser (
    Id int NOT NULL AUTO_INCREMENT,
    Name VARCHAR(255) NOT NULL,
    LoweredName VARCHAR(255) NOT NULL,
    Description VARCHAR(255) NULL,
    Password VARCHAR(128) NOT NULL,
    PasswordFormat int NOT NULL,
    PasswordSalt VARCHAR(128) NOT NULL,
    Email VARCHAR(128) NOT NULL,
    LoweredEmail VARCHAR(128) NOT NULL,
    PasswordQuestion VARCHAR(255) NULL,
    PasswordAnswer VARCHAR(255) NULL,
    Comments VARCHAR(3000) NULL,
    IsApproved bit NOT NULL,
    IsLockedOut bit NOT NULL,
    CreationDate datetime NOT NULL,
    LastActivityDate datetime NOT NULL,
    LastLoginDate datetime NOT NULL,
    LastLockedOutDate datetime NOT NULL,
    LastPasswordChangeDate datetime NOT NULL,
    FailedPwdAttemptCnt int NOT NULL,
    FailedPwdAttemptWndStart datetime NOT NULL,
    FailedPwdAnsAttemptCnt int NOT NULL,
    FailedPwdAnsAttemptWndStart datetime NOT NULL,
    PRIMARY KEY(Id));


-- Create new table Application.
CREATE TABLE Application (
    Id int NOT NULL AUTO_INCREMENT,
    Name VARCHAR(255) NOT NULL,
    LoweredName VARCHAR(255) NOT NULL,
    Description VARCHAR(255) NULL,
    PRIMARY KEY(Id));


-- Add the remaining keys, constraints and indexes for the table ApplicationRole.
CREATE INDEX ApplicationRole_IDX1 ON ApplicationRole (
    RoleId);


-- Add the remaining keys, constraints and indexes for the table Role.
ALTER TABLE Role ADD CONSTRAINT Role_UC1 UNIQUE (
    LoweredName);


-- Add the remaining keys, constraints and indexes for the table MembershipUser.
ALTER TABLE MembershipUser ADD CONSTRAINT MembershipUser_UC1 UNIQUE (
    LoweredName);


CREATE INDEX MembershipUser_IDX2 ON MembershipUser (
    LastActivityDate);


-- Add the remaining keys, constraints and indexes for the table Application.
ALTER TABLE Application ADD CONSTRAINT Application_UC1 UNIQUE (
    LoweredName);


-- Add FOREIGN KEY constraints to table ApplicationUserRole.
ALTER TABLE ApplicationUserRole
    ADD CONSTRAINT App_AppUserRole_FK1 FOREIGN KEY (
        ApplicationId)
     REFERENCES Application (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


ALTER TABLE ApplicationUserRole
    ADD CONSTRAINT User_AppUserRole_FK1 FOREIGN KEY (
        UserId)
     REFERENCES MembershipUser (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


ALTER TABLE ApplicationUserRole
    ADD CONSTRAINT Role_AppUserRole_FK1 FOREIGN KEY (
        RoleId)
     REFERENCES Role (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


-- Add FOREIGN KEY constraints to table ApplicationUser.
ALTER TABLE ApplicationUser
    ADD CONSTRAINT App_AppUser_FK1 FOREIGN KEY (
        ApplicationId)
     REFERENCES Application (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


ALTER TABLE ApplicationUser
    ADD CONSTRAINT User_AppUser_FK1 FOREIGN KEY (
        UserId)
     REFERENCES MembershipUser (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


-- Add FOREIGN KEY constraints to table ApplicationRole.
ALTER TABLE ApplicationRole
    ADD CONSTRAINT App_AppRole_FK1 FOREIGN KEY (
        ApplicationId)
     REFERENCES Application (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;


ALTER TABLE ApplicationRole
    ADD CONSTRAINT Role_AppRole_FK1 FOREIGN KEY (
        RoleId)
     REFERENCES Role (
        Id) ON UPDATE NO ACTION ON DELETE NO ACTION;
